MaterialUiTimeOfDayAdapter class
A TypeAdapter for the TimeOfDay class from package:material_ui
Uses the same binary format and default type id as TimeOfDayAdapter
- Inheritance
-
- Object
- TypeAdapter<
TimeOfDay> - MaterialUiTimeOfDayAdapter
Constructors
- MaterialUiTimeOfDayAdapter({int? typeId})
-
Constructor
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
BinaryReader reader) → TimeOfDay -
Is called when a value has to be decoded.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
BinaryWriter writer, TimeOfDay obj) → void -
Is called when a value has to be encoded.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited