read method
Is called when a value has to be decoded.
Implementation
@override
T read(BinaryReader reader) {
final totalMinutes = reader.readInt();
return _create(totalMinutes ~/ 60, totalMinutes % 60);
}
Is called when a value has to be decoded.
@override
T read(BinaryReader reader) {
final totalMinutes = reader.readInt();
return _create(totalMinutes ~/ 60, totalMinutes % 60);
}