MaterialUiTimeOfDayAdapter class

A TypeAdapter for the TimeOfDay class from package:material_ui

Uses the same binary format and default type id as TimeOfDayAdapter

Inheritance

Constructors

MaterialUiTimeOfDayAdapter({int? typeId})
Constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeId → int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(BinaryReader reader) → TimeOfDay
Is called when a value has to be decoded.
inherited
toString() → String
A string representation of this object.
inherited
write(BinaryWriter writer, TimeOfDay obj) → void
Is called when a value has to be encoded.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited